import 'package:flutter/material.dart';
import 'package:red5pro/red5_configuration.dart';
import 'package:red5pro/red5_stream_player_view.dart';

class StreamPlayerView extends StatefulWidget {
  final Red5Configuration red5configuration;
  final String streamName;

  const StreamPlayerView(
      {required this.red5configuration, required this.streamName, Key? key})
      : super(key: key);

  @override
  _StreamPlayerViewState createState() => _StreamPlayerViewState();
}

class _StreamPlayerViewState extends State<StreamPlayerView> {
  late R5StreamPlayerViewController controller;
  bool isPlaying = false;
  bool isLoading = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Red5Pro Player'),
      ),
      body: Column(
        children: [
          Expanded(
            child: Center(
              child: Stack(
                children: [
                  Red5StreamPlayerView(
                    red5configuration: widget.red5configuration,
                    streamName: widget.streamName,
                    onR5StreamPlayerViewCreated: (controller) {
                      this.controller = controller;
                      controller.streamEvent.addListener(() {
                        print(controller.streamEvent.value);
                      });
                    },
                  ),
                  Visibility(
                    visible: isLoading,
                    child: Container(
                        alignment: Alignment.center,
                        child: CircularProgressIndicator()),
                  ),
                ],
              ),
            ),
          ),
          SizedBox(
            width: double.maxFinite,
            child: TextButton(
              child: Text(isPlaying ? 'Stop' : 'Play'),
              onPressed: () {
                if (isPlaying) {
                  controller.stop().then((value) {
                    setState(() {
                      isPlaying = false;
                    });
                  });
                } else {
                  setState(() {
                    isLoading = true;
                  });
                  controller.play().then((value) {
                    setState(() {
                      isPlaying = true;
                      isLoading = false;
                    });
                  });
                }
              },
            ),
          )
        ],
      ),
    );
  }
}
