import 'dart:io';

import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:red5pro/red5_configuration.dart';
import 'package:red5pro/red5_stream_view.dart';

class StreamingView extends StatefulWidget {
  final Red5Configuration red5configuration;
  final String streamName;

  const StreamingView(
      {required this.red5configuration, required this.streamName, Key? key})
      : super(key: key);

  @override
  _StreamingViewState createState() => _StreamingViewState();
}

class _StreamingViewState extends State<StreamingView> {
  File? file;
  late R5StreamViewController r5streamViewController;
  bool isPublishing = false;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Red5Pro Streaming'),
        ),
        body: Column(
          children: [
            Expanded(
              child: Red5StreamView(
                onR5StreamViewCreated: (controller) {
                  r5streamViewController = controller;
                },
              ),
            ),
            Row(
              children: [
                Container(
                  padding: EdgeInsets.all(10),
                  child: InkWell(
                    child: SizedBox(
                      height: 60,
                      width: 60,
                      child: file != null
                          ? Image.file(file!)
                          : Icon(Icons.camera_alt),
                    ),
                    onTap: () async {
                      await r5streamViewController.stopPreview();
                      final XFile? img = await ImagePicker()
                          .pickImage(source: ImageSource.camera);
                      r5streamViewController.startPreview();
                      if (img != null) {
                        setState(() {
                          file = File(img.path);
                        });
                      }
                    },
                  ),
                ),
                Expanded(
                  child: TextButton(
                    child: Text(isPublishing ? 'Stop' : 'Start Streaming'),
                    onPressed: () {
                      if (isPublishing) {
                        r5streamViewController.stopStreaming().then((value) {
                          setState(() {
                            isPublishing = false;
                          });
                        });
                      } else {
                        r5streamViewController
                            .startStreaming(widget.red5configuration,
                                widget.streamName, RecordType.Live)
                            .then((value) {
                          setState(() {
                            isPublishing = true;
                          });
                        });
                      }
                    },
                  ),
                ),
              ],
            ),
          ],
        ),
        floatingActionButton: FloatingActionButton(
          child: Icon(Icons.cameraswitch),
          onPressed: () {
            r5streamViewController.switchCamera();
          },
        ),
      ),
    );
  }
}
